@@ -15,7 +15,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
  *  Copyright (C) 1999-2004 Olivier Fourdan (fourdan@xfce.org)
- *  Copyright (C) 2011 Peter de Ridder (peter@xfce.org)
+ *  Copyright (C) 2011-2012 Peter de Ridder (peter@xfce.org)
  *
  *  Portions based Thinice port by
  *                       Tim Gerla <timg@rrv.net>,
@@ -663,7 +663,7 @@ static void draw_shadow(GtkStyle * style, GdkWindow * window, GtkStateType state
                         cairo_stroke(cr);
                     }
                 }
-                else if (DETAIL ("dockitem_bin") || DETAIL ("dockitem") || DETAIL ("toolbar"))
+                else if (DETAIL ("handlebox_bin") || DETAIL ("handlebox") || DETAIL ("toolbar"))
                 {
                     if ((xt > 1) && (yt > 1))
                     {
@@ -695,7 +695,7 @@ static void draw_shadow(GtkStyle * style, GdkWindow * window, GtkStateType state
                         cairo_stroke(cr);
                     }
                 }
-                else if (DETAIL("vscrollbar") || DETAIL("hscrollbar") || DETAIL("bar") || DETAIL("slider") || DETAIL("vscale") || DETAIL("hscale"))
+                else if (DETAIL("vscrollbar") || DETAIL("hscrollbar") || DETAIL("slider") || DETAIL("vscale") || DETAIL("hscale"))
                 {
                     if ((xt > 1) && (yt > 1))
                     {
@@ -736,7 +736,7 @@ static void draw_shadow(GtkStyle * style, GdkWindow * window, GtkStateType state
                         cairo_stroke(cr);
                     }
                 }
-                else if (DETAIL("menubar") || DETAIL("frame") || DETAIL("dockitem") || DETAIL("dockitem_bin") || DETAIL("menu") || DETAIL("toolbar"))
+                else if (DETAIL("frame"))
                 {
                     if ((xt > 1) && (yt > 1))
                     {
@@ -864,7 +864,7 @@ static void draw_shadow(GtkStyle * style, GdkWindow * window, GtkStateType state
                         cairo_stroke(cr);
                     }
                 }
-                else if (DETAIL ("dockitem_bin") || DETAIL ("dockitem") || DETAIL ("toolbar"))
+                else if (DETAIL ("handlebox_bin") || DETAIL ("handlebox") || DETAIL ("toolbar"))
                 {
                     if ((xt > 1) && (yt > 1))
                     {
@@ -987,6 +987,7 @@ static void draw_check(GtkStyle * style, GdkWindow * window, GtkStateType state,
     cairo_t *cr;
     guint size;
     guint w, b;
+    GdkColor * c;
 
     CHECK_ARGS;
     SANITIZE_SIZE;
@@ -1023,13 +1024,18 @@ static void draw_check(GtkStyle * style, GdkWindow * window, GtkStateType state,
 
     cairo_set_antialias (cr, CAIRO_ANTIALIAS_NONE);
 
-    cairo_rectangle (cr, x + 0.5, y + 0.5, width - 1, height - 1);
+    cairo_rectangle (cr, x + 0.5, y + 0.5, size - 1, size - 1);
 
     if (!DETAIL("check"))    /* not Menu item */
     {
         /* Draw the background */
         gdk_cairo_set_source_color(cr, &style->base[state]);
         cairo_fill_preserve(cr);
+        c = &style->text[state];
+    }
+    else
+    {
+        c = &style->fg[state];
     }
 
     /* Draw the border */
@@ -1046,7 +1052,7 @@ static void draw_check(GtkStyle * style, GdkWindow * window, GtkStateType state,
         w = ((size + 4 - b) / 6);
 
         /* Draw the check */
-        gdk_cairo_set_source_color(cr, &style->fg[state]);
+        gdk_cairo_set_source_color(cr, c);
 
         cairo_move_to (cr, x + b, y + floor(size / 2 - 1.5));
 
@@ -1066,8 +1072,7 @@ static void draw_check(GtkStyle * style, GdkWindow * window, GtkStateType state,
     }
     else if (shadow == GTK_SHADOW_ETCHED_IN)
     {
-        gdk_cairo_set_source_color(cr, &style->fg[state]);
-        draw_dash(cr, &style->fg[state], x, y, size);
+        draw_dash(cr, c, x, y, size);
     }
 
     cairo_destroy(cr);
@@ -1077,6 +1082,7 @@ static void draw_option(GtkStyle * style, GdkWindow * window, GtkStateType state
 {
     cairo_t *cr;
     guint size;
+    GdkColor * c;
 
     CHECK_ARGS;
     SANITIZE_SIZE;
@@ -1113,13 +1119,18 @@ static void draw_option(GtkStyle * style, GdkWindow * window, GtkStateType state
 
     cairo_set_antialias (cr, CAIRO_ANTIALIAS_NONE);
 
-    cairo_arc (cr, x + (width / 2.0), y + (height / 2.0), width / 2, 0, 2 * M_PI);
+    cairo_arc (cr, x + (size / 2.0), y + (size / 2.0), (size - 1) / 2.0, 0, 2 * M_PI);
 
     if (!DETAIL("option"))   /* not Menu item */
     {
         /* Draw the background */
         gdk_cairo_set_source_color(cr, &style->base[state]);
         cairo_fill_preserve(cr);
+        c = &style->text[state];
+    }
+    else
+    {
+        c = &style->fg[state];
     }
 
     /* Draw the border */
@@ -1133,14 +1144,14 @@ static void draw_option(GtkStyle * style, GdkWindow * window, GtkStateType state
     if (shadow == GTK_SHADOW_IN)
     {
         /* Draw the dot */
-        gdk_cairo_set_source_color(cr, &style->fg[state]);
+        gdk_cairo_set_source_color(cr, c);
 
         cairo_arc (cr, x + (size / 2.0), y + (size / 2.0), (size / 2.0) - ((size + 2) / 5), 0, 2 * M_PI);
         cairo_fill(cr);
     }
     else if (shadow == GTK_SHADOW_ETCHED_IN)
     {
-        draw_dash(cr, &style->fg[state], x, y, size);
+        draw_dash(cr, c, x, y, size);
     }
 
     cairo_destroy(cr);
@@ -1468,7 +1479,7 @@ static void draw_extension(GtkStyle * style, GdkWindow * window, GtkStateType st
     CHECK_ARGS;
     SANITIZE_SIZE;
 
-    gtk_style_apply_default_background(style, window, widget && !GTK_WIDGET_NO_WINDOW(widget), GTK_STATE_NORMAL, area, x, y, width, height);
+    gtk_style_apply_default_background(style, window, widget && !GTK_WIDGET_NO_WINDOW(widget), state_type, area, x, y, width, height);
 
     if (XFCE_RC_STYLE(style->rc_style)->smooth_edge)
     {
